pub struct RoutineSet {
pub index: u32,
pub type: String,
pub weight_kg: Option<f64>,
pub reps: Option<f64>,
pub rep_range: Option<RepRange>,
pub distance_meters: Option<f64>,
pub duration_seconds: Option<f64>,
pub rpe: Option<f64>,
pub custom_metric: Option<f64>,
}Expand description
A set belonging to an exercise within a Routine, as returned by the API.
Fields
index: u32Index indicating the order of the set within the exercise.
type: StringThe type of set: one of normal, warmup, dropset, failure.
weight_kg: Option<f64>Weight lifted, in kilograms.
reps: Option<f64>Number of reps logged for the set.
rep_range: Option<RepRange>A target rep range for the set, if applicable.
distance_meters: Option<f64>Number of meters logged for the set.
duration_seconds: Option<f64>Number of seconds logged for the set.
rpe: Option<f64>Rating of Perceived Exertion logged for the set.
custom_metric: Option<f64>Custom metric logged for the set.