pub struct WorkoutExerciseInput {
pub exercise_template_id: String,
pub superset_id: Option<i64>,
pub notes: Option<String>,
pub sets: Vec<WorkoutSetInput>,
}Expand description
An exercise to include when creating or updating a workout.
Fields
exercise_template_id: StringThe ID of the exercise template.
superset_id: Option<i64>The ID of the superset this exercise belongs to, if any.
notes: Option<String>Additional notes for the exercise.
sets: Vec<WorkoutSetInput>The sets performed for this exercise.
Implementations